@@ -3,7 +3,7 @@ package Debian::AptContents;
 use strict;
 use warnings;
 
-our $VERSION = '0.95';
+our $VERSION = '0.99';
 
 =head1 NAME
 
@@ -157,7 +157,7 @@ sub get_contents_files {
         chomp($line);
         next unless $line =~ m/^Contents-deb/;
         my ( $index_name, $arch, $suite, $filename ) = split( ' ', $line, 4 );
-        next unless $arch eq $archspec;
+        next unless $arch eq $archspec or $arch eq 'all';
         if ( $self->dist ) {
             next unless $suite eq $self->dist;
         }
@@ -177,6 +177,48 @@ invocation.
 
 =cut
 
+# distribute files so that the load (measured by file size) is distributed
+# more or less equally
+sub _distribute_files {
+    my ( $self, $files, $cpus ) = @_;
+
+    $cpus = scalar(@$files) if scalar(@$files) < $cpus;
+
+    return $files unless $cpus > 1;
+
+    my @data = map( { file => $_, size => -s $_ }, @$files );
+    @data = sort { $b->{size} <=> $a->{size} } @data;
+
+    my ( @slots, @slot_load );
+    for(1..$cpus) {
+        push @slots, [];
+        push @slot_load, 0;
+    }
+
+    for my $item (@data) {
+        my $lightest_slot = 0;
+        my $lightest_slot_load = $slot_load[0];
+        for my $slot ( 1 .. $#slots ) {
+            next unless $slot_load[$slot] < $lightest_slot_load;
+
+            $lightest_slot      = $slot;
+            $lightest_slot_load = $slot_load[$slot];
+        }
+
+        push @{ $slots[$lightest_slot] }, $item->{file};
+        $slot_load[$lightest_slot] += $item->{size};
+    }
+
+    if (0) {
+        for my $slot (@slots) {
+            warn "Slot package: \n";
+            warn sprintf( "  %8d=%s\n", -s $_, $_ ) for @$slot;
+        }
+    }
+
+    return @slots;
+}
+
 sub read_cache {
     my $self = shift;
 
@@ -217,37 +259,134 @@ sub read_cache {
             $cache->{apt_contents}   = {};
 
             push @{ $cache->{contents_files} }, @{ $self->contents_files };
-            my @cat_cmd = (
-                '/usr/lib/apt/apt-helper', 'cat-file', @{ $self->contents_files }
-            );
-            open( my $f, "-|", @cat_cmd )
-                or die
-                "Can't run '/usr/lib/apt/apt-helper cat-file' on Contents files: $!\n";
 
-            $self->warning( 1,
-                "Parsing Contents files:\n\t"
-                    . join( "\n\t", @{ $self->contents_files } ) );
-            my $line;
-            while ( defined( $line = $f->getline ) ) {
-                my ( $file, $packages ) = split( /\s+/, $line );
-                next unless $file =~ s{
-                    ^usr/
-                    (?:share|lib)/
-                    (?:perl\d+/            # perl5/
-                    | perl/(?:\d[\d.]+)/   # or perl/5.10/
-                    | \S+-\S+-\S+/perl\d+/(?:\d[\d.]+)/  # x86_64-linux-gnu/perl5/5.22/
-                    )
-                }{}x;
-                $cache->{apt_contents}{$file} = exists $cache->{apt_contents}{$file}
-                    ? $cache->{apt_contents}{$file}.','.$packages
-                    : $packages;
-
-                # $packages is a comma-separated list of
-                # section/package items. We'll parse it when a file
-                # matches. Otherwise we'd parse thousands of entries,
-                # while checking only a couple
+            {
+                my $prefix;
+                for my $f ( @{ $self->contents_files } ) {
+                    if ( defined($prefix) ) {
+                        chop($prefix)
+                            while length($prefix)
+                            and not $f =~ /^\Q$prefix\E/;
+                    }
+                    else {
+                        $prefix = $f;
+                    }
+                }
+                $self->warning(
+                    1,
+                    "Parsing Contents files:\n\t"
+                        . join( "\n\t",
+                        map { my $x = $_; $x =~ s{^\Q$prefix\E}{}; $x }
+                            @{ $self->contents_files } )
+                );
+            }
+
+            require IO::Pipe; require IO::Select;
+            my $cpus = eval { require Sys::CPU; Sys::CPU::cpu_count() };
+            unless ($cpus) {
+                $self->warning( 1, "Sys::CPU not available");
+                $self->warning( 1, "Using single parser process");
+                $cpus = 1;
+            }
+
+            # parsing of Contents files goes to forked children. contents_files
+            # is sorted by size, so that no child can have only long Contents.
+            # the number of children is capped to the number of CPUs on the system
+            my ( @kids, %kid_by_fh );
+            for my $portion (
+                $self->_distribute_files( $self->contents_files, $cpus ) )
+            {
+                push @kids, { files => $portion, lines => 0 };
+            }
+
+            my $sel = IO::Select->new;
+
+            # start the children
+            for my $kid (@kids) {
+                my $pipe = IO::Pipe->new;
+                if ( my $pid = fork() ) {    # parent
+                    $pipe->reader;
+
+                    $kid_by_fh{ $pipe->fileno } = $kid;
+                    $kid->{io}                  = $pipe;
+                    $kid->{pid}                 = $pid;
+                    $sel->add( $pipe->fileno );
+                }
+                elsif ( defined($pid) ) {    # child
+                    $pipe->writer;
+                    my @cat_cmd = (
+                        '/usr/lib/apt/apt-helper', 'cat-file',
+                        @{ $kid->{files} }
+                    );
+
+                    open( my $f, "-|", @cat_cmd )
+                        or die sprintf( "Error running '%s': %d\n",
+                        join( ' ', @cat_cmd ), $! );
+
+                    my $line;
+                    while ( defined( $line = $f->getline ) ) {
+                        my ( $file, $packages ) = split( /\s+/, $line );
+                        next unless $file =~ s{
+                            ^usr/
+                            (?:share|lib)/
+                            (?:perl\d+/            # perl5/
+                            | perl/(?:\d[\d.]+)/   # or perl/5.10/
+                            | \S+-\S+-\S+/perl\d+/(?:\d[\d.]+)/  # x86_64-linux-gnu/perl5/5.22/
+                            )
+                        }{}x;
+                        $pipe->print("$file\t$packages\n");
+                    }
+                    close($f);
+                    close($pipe);
+                    exit(0);
+                }
+                else {
+                    die "fork(): $!";
+                }
+            }
+
+            # read children's output
+            while ( $sel->count
+                and my @ready = IO::Select->select( $sel, undef, $sel ) )
+            {
+                my ( $to_read, undef, $errs ) = @ready;
+
+                for my $fh (@$to_read) {
+                    my $kid = $kid_by_fh{$fh};
+                    my $io = $kid->{io}; my $file = $kid->{file};
+                    if ( defined( my $line = <$io> ) ) {
+                        chomp($line);
+                        $kid->{lines}++;
+                        my ( $file, $packages ) = split( '\t', $line );
+                        $cache->{apt_contents}{$file} =
+                            exists $cache->{apt_contents}{$file}
+                            ? $cache->{apt_contents}{$file} . ',' . $packages
+                            : $packages;
+
+                        # $packages is a comma-separated list of
+                        # section/package items. We'll parse it when a file
+                        # matches. Otherwise we'd parse thousands of entries,
+                        # while checking only a couple
+                    }
+                    else {
+                        warn sprintf( "child %d (%s) EOF after %d lines\n",
+                            $kid->{pid}, $kid->{file}, $kid->{lines} )
+                            if 0;
+                        $sel->remove($fh);
+                        close( $kid->{io} );
+                        waitpid( $kid->{pid}, 0 );
+                    }
+                }
+
+                for my $fh (@$errs) {
+                    my $kid = $kid_by_fh{$fh};
+                    $sel->remove($fh);
+                    close( $kid->{io} );
+                    waitpid( $kid->{pid}, 0 );
+                    die sprintf( "child %d (%s) returned %d\n",
+                        $kid->{pid}, join( ', ', @{ $kid->{files} } ), $? );
+                }
             }
-            close($f);
 
             if ( %{ $cache->{apt_contents} } ) {
                 $self->cache($cache);
@@ -415,7 +554,7 @@ sub find_perl_module_package {
 
 =over 4
 
-=item Copyright (C) 2008, 2009, 2010 Damyan Ivanov <dmn@debian.org>
+=item Copyright (C) 2008, 2009, 2010, 2017 Damyan Ivanov <dmn@debian.org>
 
 =item Copyright (C) 2016, gregor herrmann <gregoa@debian.org>
 
