@@ -25,13 +25,14 @@ require v5.10.0;
 use strict;
 use warnings;
 
-our $VERSION = '0.95';
+our $VERSION = '0.99';
 
 use base qw( Class::Accessor Tie::IxHash );
 
 use Carp qw(croak);
 use Debian::Control::Stanza::CommaSeparated;
 use Debian::Dependencies;
+use Sub::Install;
 
 =head1 FIELDS
 
@@ -44,6 +45,15 @@ Fields that are to contain dependency lists (as per L</is_dependency_list>
 method below) are automatically converted to instances of the
 L<Debian::Dependencies> class.
 
+=head2 User-defined fields
+
+User-defined fields are supported. These start with C<X>, optionally followed
+by C<S>, C<B> or C<C>, then C<_>, capital letter and other letters and digits.
+
+Examples: C<X_Moon_Phase>, C<XS_Hemisphere>.
+
+See L<https://www.debian.org/doc/debian-policy/#user-defined-fields>.
+
 =cut
 
 use constant fields => ();
@@ -98,6 +108,7 @@ sub new {
         # translate field name into the accessor canonical name
         $k = $canonical{ lc $k } || $k;
         $self->can($k)
+            or $self->looks_like_an_x_field($k)
             or croak "Invalid field given ($k)";
         $self->$k($v);
     }
@@ -117,6 +128,40 @@ sub new {
     return $self;
 }
 
+our $AUTOLOAD;
+sub AUTOLOAD {
+    my $self = shift;
+
+    ref($self) and eval { $self->isa(__PACKAGE__) }
+        or croak "Invalid method call";
+
+    my $field = $AUTOLOAD;
+    $field =~ s/.+:://;
+
+    if ( $field eq 'DESTROY' ) {
+        return eval { $self->SUPER::DESTROY(@_) };
+    }
+
+    $self->looks_like_an_x_field($field)
+        or croak "Invalid field '$field' requested";
+
+    Sub::Install::install_sub({
+            code => sub {
+                my $self = shift;
+                if (@_) {
+                    $self->set( $field, @_ );
+                }
+                else {
+                    $self->get($field);
+                }
+            },
+            into => ref($self),
+            as => $field,
+        });
+
+    $self->$field(@_);
+}
+
 =head1 METHODS
 
 =over
@@ -202,6 +247,19 @@ sub is_comma_separated {
     return exists $comma_separated{$field};
 }
 
+=item looks_like_an_x_field($field)
+
+Returns true if B<$field> is considered appropriate to name a user-defined
+field.
+
+=cut
+
+sub looks_like_an_x_field {
+    my ( $self, $field ) = @_;
+
+    return $field =~ /^X[SBC]?(?:_[A-Z][A-Za-z0-9]*)+$/;
+}
+
 =item get($field)
 
 Overrides the default get method from L<Class::Accessor> with L<Tie::IxHash>'s
@@ -322,7 +380,7 @@ sub as_string
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright (C) 2009 Damyan Ivanov L<dmn@debian.org>
+Copyright (C) 2009, 2017 Damyan Ivanov L<dmn@debian.org>
 
 This program is free software; you can redistribute it and/or modify it under
 the terms of the GNU General Public License version 2 as published by the Free
