@@ -55,6 +55,10 @@ replaced with underscores.
 
 =item Provides
 
+=item Built_Using
+
+=item Multi_Arch
+
 =item Description
 
 =back
@@ -87,14 +91,14 @@ package Debian::Control::Stanza::Binary;
 use strict;
 use warnings;
 
-our $VERSION = '0.95';
+our $VERSION = '0.99';
 
 use base 'Debian::Control::Stanza';
 
 use constant fields => qw(
     Package Architecture Section Priority Essential Depends Recommends Suggests
-    Enhances Replaces Pre_Depends Conflicts Breaks Provides Built_Using Description
-    _short_description _long_description
+    Enhances Replaces Pre_Depends Conflicts Breaks Provides Built_Using Multi_Arch
+    Description _short_description _long_description
 );
 
 =head1 CONSTRUCTOR
