@@ -61,10 +61,10 @@ replaced with underscores.
 
 =item Homepage
 
-=item XS_Autobuild
-
 =item Testsuite
 
+=item Rules_Requires_Root
+
 =back
 
 All Build_... fields are converted into objects of L<Debian::Dependencies>
@@ -77,7 +77,7 @@ package Debian::Control::Stanza::Source;
 use strict;
 use warnings;
 
-our $VERSION = '0.95';
+our $VERSION = '0.99';
 
 use base qw(Debian::Control::Stanza);
 
@@ -85,7 +85,7 @@ use constant fields => qw (
     Source Section Priority Maintainer Uploaders DM_Upload_Allowed 
     Build_Conflicts Build_Conflicts_Indep Build_Depends Build_Depends_Indep
     Standards_Version Vcs_Browser Vcs_Bzr Vcs_CVS Vcs_Git Vcs_Svn Homepage
-    XS_Autobuild Testsuite
+    Testsuite Rules_Requires_Root
 );
 
 =head1 CONSTRUCTOR
