@@ -3,7 +3,7 @@ package DhMakePerl::Command::Packaging;
 use strict;
 use warnings;
 
-our $VERSION = '0.95';
+our $VERSION = '0.99';
 
 use feature 'switch';
 
@@ -45,7 +45,7 @@ use Text::Balanced qw(extract_quotelike);
 use Text::Wrap qw(fill);
 use User::pwent;
 
-use constant debstdversion => '3.9.8';
+use constant debstdversion => '4.1.3';
 
 our %DEFAULTS = (
 );
@@ -293,9 +293,6 @@ sub extract_basic {
         find( sub { $self->check_for_xs }, $self->main_dir );
     }
 
-    $self->cfg->dh('9')
-        if not $self->cfg->_explicitly_set->{dh};
-
     printf(
         "Found: %s %s (%s arch=%s)\n",
         $self->perlname, $self->version,
@@ -816,6 +813,8 @@ sub extract_docs {
     my $dir = $self->main_dir;
 
     $dir .= '/' unless $dir =~ m(/$);
+
+    my $toplevelreadme_re = $self->main_dir . '/README(?:\.\w+)?$';
     find(
         {   preprocess => sub {
                 my $bn = basename $File::Find::dir;
@@ -832,7 +831,7 @@ sub extract_docs {
                     substr( $File::Find::name, length($dir) )
                     )
                     if (
-                        $File::Find::name ne $self->main_dir . '/README'
+                        $File::Find::name !~ m{$toplevelreadme_re}i
                     and /^\b(README|TODO|BUGS|NEWS|ANNOUNCE|CONTRIBUTING)\b/i
                     and !/\.(pod|pm)$/
                     and ( !$self->cfg->exclude
