@@ -2,7 +2,7 @@ package DhMakePerl::Command::make;
 
 use warnings;
 use strict;
-our $VERSION = '0.95';
+our $VERSION = '0.99';
 use 5.010;    # we use smart matching
 
 use base 'DhMakePerl::Command::Packaging';
@@ -190,11 +190,11 @@ sub execute {
         }
         elsif ( $vcs eq 'git' ) {
             $self->control->source->Vcs_Git(
-                sprintf( "https://anonscm.debian.org/git/pkg-perl/packages/%s.git",
+                sprintf( "https://salsa.debian.org/perl-team/modules/packages/%s.git",
                     $self->pkgname )
             );
             $self->control->source->Vcs_Browser(
-                sprintf( "https://anonscm.debian.org/cgit/pkg-perl/packages/%s.git",
+                sprintf( "https://salsa.debian.org/perl-team/modules/packages/%s",
                     $self->pkgname )
             );
         }
@@ -527,7 +527,7 @@ sub create_changelog {
 
     $fh->printf( "%s (%s) %s; urgency=low\n",
         $self->srcname, $self->pkgversion, $changelog_dist );
-    $fh->print("\n  * Initial Release.$closes\n\n");
+    $fh->print("\n  * Initial release.$closes\n\n");
     $fh->printf( " -- %s  %s\n", $self->get_developer,
         email_date(time) );
 
